==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu.md <==
# AmazonBraketQpu


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')
```



| Illustration | AmazonBraketQpu | AmazonBraketQpuCard | AmazonBraketQpuGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu.png) | ![illustration for AmazonBraketQpu](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu.Local.png) | ![illustration for AmazonBraketQpuCard](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpuCard.Local.png) | ![illustration for AmazonBraketQpuGroup](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpuGroup.Local.png) |




## AmazonBraketQpu

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpu
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpu('AmazonBraketQpu', 'Amazon Braket Qpu', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpu
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpu('AmazonBraketQpu', 'Amazon Braket Qpu', 'an optional tech label')
@enduml
```

## AmazonBraketQpuCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpuCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpuCard('AmazonBraketQpuCard', 'Amazon Braket Qpu Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpuCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpuCard('AmazonBraketQpuCard', 'Amazon Braket Qpu Card', 'an optional description')
@enduml
```

## AmazonBraketQpuGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpuGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpuGroup('AmazonBraketQpuGroup', 'Amazon Braket Qpu Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpuGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpuGroup('AmazonBraketQpuGroup', 'Amazon Braket Qpu Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu.md <==
# AmazonBraketQpu


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')
```



| Illustration | AmazonBraketQpu | AmazonBraketQpuCard | AmazonBraketQpuGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu.png) | ![illustration for AmazonBraketQpu](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu.Local.png) | ![illustration for AmazonBraketQpuCard](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpuCard.Local.png) | ![illustration for AmazonBraketQpuGroup](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpuGroup.Local.png) |




## AmazonBraketQpu

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpu
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpu('AmazonBraketQpu', 'Amazon Braket Qpu', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpu
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpu('AmazonBraketQpu', 'Amazon Braket Qpu', 'an optional tech label')
@enduml
```

## AmazonBraketQpuCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpuCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpuCard('AmazonBraketQpuCard', 'Amazon Braket Qpu Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpuCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpuCard('AmazonBraketQpuCard', 'Amazon Braket Qpu Card', 'an optional description')
@enduml
```

## AmazonBraketQpuGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpuGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpuGroup('AmazonBraketQpuGroup', 'Amazon Braket Qpu Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketQpuGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketQpu')

' renders the element
AmazonBraketQpuGroup('AmazonBraketQpuGroup', 'Amazon Braket Qpu Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
